@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: main.c,v 1.28.2.6 2004/06/12 03:26:29 fuyu Exp $
+ * $Id: main.c,v 1.28.2.7 2004/06/13 02:35:01 fuyu Exp $
  */
 
 #include "config.h"
@@ -70,13 +70,10 @@ ochusha_gdk_threads_enter(void)
 {
   g_static_rec_mutex_lock(&ochusha_gdk_threads_lock);
   lock_depth++;
-#if 0
+#if ENABLE_STRICT_CHECK		/* ѥå */
   if (lock_depth > 1)
     fprintf(stderr, "gdk_threads_enter(): depth=%d\n", lock_depth);
 #endif
-#if ENABLE_STRICT_CHECK		/* Ѥθå */
-  g_assert(lock_depth == 1);
-#endif
 }
 
 
