@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: virtual_board.c,v 1.18 2004/01/24 07:04:14 fuyu Exp $
+ * $Id: virtual_board.c,v 1.21.2.1 2004/05/30 14:53:41 fuyu Exp $
  */
 
 #include "config.h"
@@ -198,6 +198,23 @@ update_board_list(gpointer list_data, gpointer user_data)
 }
 
 
+static void
+remove_thread(OchushaBBSThread *thread, VirtualBoard *virtual_board)
+{
+  OchushaBulletinBoard *board = OCHUSHA_BULLETIN_BOARD(virtual_board);
+#if 0
+  fprintf(stderr, "thread: %s removed.\n", thread->id);
+#endif
+  g_hash_table_remove(board->thread_table, thread->id);
+  board->thread_list = g_slist_remove(board->thread_list, thread);
+  virtual_board->recent_thread_list
+    = g_slist_remove(virtual_board->recent_thread_list, thread);
+  g_slist_free(virtual_board->board_list);
+  virtual_board->board_list = NULL;
+  g_slist_foreach(board->thread_list, update_board_list, virtual_board);
+}
+
+
 gboolean
 virtual_board_remove_thread(VirtualBoard *virtual_board,
 			    OchushaBBSThread *thread)
@@ -209,17 +226,10 @@ virtual_board_remove_thread(VirtualBoard *virtual_board,
   if (!ochusha_bulletin_board_trylock_thread_list(board))
     return FALSE;
 
-  if (g_hash_table_remove(board->thread_table, thread->id))
-    {
-      board->thread_list = g_slist_remove(board->thread_list, thread);
-      virtual_board->recent_thread_list
-	= g_slist_remove(virtual_board->recent_thread_list, thread);
-      g_slist_free(virtual_board->board_list);
-      virtual_board->board_list = NULL;
-      g_slist_foreach(board->thread_list, update_board_list, virtual_board);
-    }
+  remove_thread(thread, virtual_board);
 
   ochusha_bulletin_board_unlock_thread_list(board);
+
   return TRUE;
 }
 
@@ -268,21 +278,19 @@ compare_by_id(OchushaBBSThread *a, OchushaBBSThread *b)
 }
 
 
-void
+static void
 collect_unread_thread(OchushaBBSThread *thread, GSList **removed_list_p)
 {
-  if (ochusha_bbs_thread_get_number_of_responses_read(thread) == 0)
+  ThreadProxy *proxy;
+  g_assert(IS_THREAD_PROXY(thread));
+  proxy = THREAD_PROXY(thread);
+
+  if (ochusha_bbs_thread_get_number_of_responses_read(thread) == 0
+      || proxy->real_thread == NULL)
     *removed_list_p = g_slist_append(*removed_list_p, thread);
 }
 
 
-void
-remove_thread(OchushaBBSThread *thread, VirtualBoard *virtual_board)
-{
-  virtual_board_remove_thread(virtual_board, thread);
-}
-
-
 void
 virtual_board_clean_up_threadlist(VirtualBoard *virtual_board,
 				  gboolean remove_unread_thread)
@@ -355,6 +363,7 @@ virtual_board_bbs_thread_new(OchushaBulletinBoard *board, const char *id,
   VirtualBoard *virtual_board;
   OchushaBBSThread *thread;
   OchushaBulletinBoard *real_board = NULL;
+  char *real_id = NULL;
   BulletinBoardGUIInfo *info;
   g_return_val_if_fail(IS_VIRTUAL_BOARD(board), NULL);
   g_return_val_if_fail(id != NULL && title != NULL, NULL);
@@ -369,8 +378,8 @@ virtual_board_bbs_thread_new(OchushaBulletinBoard *board, const char *id,
 #endif
 
   if (ochusha_bbs_table_check_url(virtual_board->application->table, id,
-				  &real_board, NULL, NULL, NULL, NULL, NULL,
-				  NULL))
+				  &real_board, NULL, NULL, &real_id,
+				  NULL, NULL, NULL))
     {
       if (real_board != NULL)
 	{
@@ -388,12 +397,35 @@ virtual_board_bbs_thread_new(OchushaBulletinBoard *board, const char *id,
 							   virtual_board->application->session_subdir,
 							   TRUE);
 	    }
-	  real_thread = ochusha_bulletin_board_lookup_bbs_thread_by_url(real_board, id);
+	  real_thread
+	    = ochusha_bulletin_board_lookup_bbs_thread_by_url(real_board,
+							      virtual_board->application->broker,
+							      id);
+	  if (real_thread == NULL && real_id != NULL)
+	    {
+#if 0
+	      fprintf(stderr, "real_thread may have been dead: %s\n", id);
+#endif
+	      real_thread = ochusha_bulletin_board_bbs_thread_new(real_board,
+								  real_id,
+								  title);
+	      thread->flags |= OCHUSHA_BBS_THREAD_DAT_DROPPED;
+	    }
 	  if (real_thread != NULL)
 	    thread_proxy_set_real_thread(THREAD_PROXY(thread), real_thread);
+#if 0
 	  else
 	    fprintf(stderr, "Couldn't find real_thread by URL: %s\n", id);
+#endif
 	}
+#if 0
+      else
+	{
+	  fprintf(stderr, "Couldn't find real board by URL: %s\n", id);
+	}
+#endif
+      if (real_id != NULL)
+	G_FREE(real_id);
     }
 
   info = ensure_bulletin_board_info(board, virtual_board->application);
@@ -480,6 +512,42 @@ internal_each_thread_cb(OchushaBBSThread *thread, gpointer user_data)
 }
 
 
+static void
+start_parsing_cb(gpointer user_data)
+{
+  RefreshThreadlistArgs *args = (RefreshThreadlistArgs *)user_data;
+  if (args->start_parsing_cb != NULL)
+    (*args->start_parsing_cb)(args->callback_data);
+}
+
+
+static void
+before_wait_cb(gpointer user_data)
+{
+  RefreshThreadlistArgs *args = (RefreshThreadlistArgs *)user_data;
+  if (args->before_wait_cb != NULL)
+    (*args->before_wait_cb)(args->callback_data);
+}
+
+
+static void
+after_wait_cb(gpointer user_data)
+{
+  RefreshThreadlistArgs *args = (RefreshThreadlistArgs *)user_data;
+  if (args->after_wait_cb != NULL)
+    (*args->after_wait_cb)(args->callback_data);
+}
+
+
+static void
+end_parsing_cb(gpointer user_data)
+{
+  RefreshThreadlistArgs *args = (RefreshThreadlistArgs *)user_data;
+  if (args->end_parsing_cb != NULL)
+    (*args->end_parsing_cb)(args->callback_data);
+}
+
+
 static void
 update_by_board(gpointer list_data, gpointer user_data)
 {
@@ -505,10 +573,10 @@ update_by_board(gpointer list_data, gpointer user_data)
   if (!ochusha_bulletin_board_refresh_threadlist(OCHUSHA_BULLETIN_BOARD(list_data),
 						 buffer,
 						 internal_each_thread_cb,
-						 args->start_parsing_cb,
-						 args->before_wait_cb,
-						 args->after_wait_cb,
-						 args->end_parsing_cb,
+						 start_parsing_cb,
+						 before_wait_cb,
+						 after_wait_cb,
+						 end_parsing_cb,
 						 user_data))
     {
       /* subject.txtŪʤΤƤߤ줿 */
@@ -554,9 +622,11 @@ virtual_board_refresh_threadlist(OchushaBulletinBoard *board,
   info = ensure_bulletin_board_info(board, virtual_board->application);
 
   if ((args.mode == OCHUSHA_NETWORK_BROKER_CACHE_ONLY
-       || info->use_static_threadlist)
-      && virtual_board->recent_thread_list != NULL)
+       || info->use_static_threadlist))
     {
+      if (virtual_board->recent_thread_list == NULL)
+	virtual_board_clean_up_threadlist(virtual_board, FALSE);
+
       if (start_parsing_cb != NULL)
 	(*start_parsing_cb)(callback_data);
 
