@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: monitor.c,v 1.1.2.4 2004/06/12 03:30:39 fuyu Exp $
+ * $Id: monitor.c,v 1.1.2.5 2004/06/13 02:22:42 fuyu Exp $
  */
 
 #include "config.h"
@@ -125,6 +125,20 @@ ochusha_monitor_enter(Monitor *monitor)
 	  return;
 	}
 
+#if CHECK_LOCK_ORDER
+      if (monitor->other != NULL)
+	{
+	  pthread_t self = pthread_self();
+	  if (monitor->other->count > 0
+	      && pthread_equal(monitor->other->locker, self))
+	    {
+	      fprintf(stderr, "Lock Order Reversal: %p should follow %p\n",
+		      monitor->other, monitor);
+	      abort();
+	    }
+	}
+#endif
+
       if ((result = pthread_mutex_lock(&monitor->mutex)) != 0)
 	{
 	  fprintf(stderr, "Couldn't lock a mutex: %s(%d)\n",
@@ -147,7 +161,19 @@ ochusha_monitor_try_enter(Monitor *monitor)
   int result = pthread_mutex_trylock(&monitor->mutex);
   if (result == 0)
     {
+#if CHECK_LOCK_ORDER
+      pthread_t self = pthread_self();
+      if (monitor->other != NULL && monitor->other->count > 0
+	  && pthread_equal(monitor->other->locker, self))
+	{
+	  fprintf(stderr, "Lock Order Reversal: %p should follow %p\n",
+		  monitor->other, monitor);
+	  abort();
+	}
+      monitor->locker = self;
+#else
       monitor->locker = pthread_self();
+#endif
       monitor->count = 1;
       return 1;
     }
@@ -162,6 +188,19 @@ ochusha_monitor_try_enter(Monitor *monitor)
 #endif
 	  return 1;
 	}
+#if CHECK_LOCK_ORDER
+      if (monitor->other != NULL)
+	{
+	  pthread_t self = pthread_self();
+	  if (monitor->other->count > 0
+	      && pthread_equal(monitor->other->locker, self))
+	    {
+	      fprintf(stderr, "Lock Order Reversal: %p should follow %p\n",
+		      monitor->other, monitor);
+	      abort();
+	    }
+	}
+#endif
       return 0;
     }
 
@@ -202,6 +241,19 @@ ochusha_monitor_wait(Monitor *monitor)
   prev_count = monitor->count;
   monitor->count = 0;
 
+#if CHECK_LOCK_ORDER
+  if (monitor->other != NULL)
+    {
+      pthread_t self = pthread_self();
+      if (monitor->other->count > 0
+	  && pthread_equal(monitor->other->locker, self))
+	{
+	  fprintf(stderr, "Lock Order Reversal: attemplt to wait on %p during %p held.\n", monitor, monitor->other);
+	  abort();
+	}
+    }
+#endif
+
   if ((result = pthread_cond_wait(&monitor->cond, &monitor->mutex)) != 0)
     {
       fprintf(stderr, "Couldn't wait a condition: %s(%d)\n",
@@ -239,6 +291,19 @@ ochusha_monitor_timedwait(Monitor *monitor, long ms)
   prev_count = monitor->count;
   monitor->count = 0;
 
+#if CHECK_LOCK_ORDER
+  if (monitor->other != NULL)
+    {
+      pthread_t self = pthread_self();
+      if (monitor->other->count > 0
+	  && pthread_equal(monitor->other->locker, self))
+	{
+	  fprintf(stderr, "Lock Order Reversal: attemplt to wait on %p during %p held.\n", monitor, monitor->other);
+	  abort();
+	}
+    }
+#endif
+
   if (ms == 0)
     {
       if ((result = pthread_cond_wait(&monitor->cond, &monitor->mutex)) != 0)
