@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_network_broker.c,v 1.60.2.5 2004/05/24 10:02:27 fuyu Exp $
+ * $Id: ochusha_network_broker.c,v 1.60.2.6 2004/06/13 02:24:07 fuyu Exp $
  */
 
 #include "config.h"
@@ -32,6 +32,7 @@
 #include "ochusha.h"
 #include "ochusha_network_broker.h"
 
+#include "monitor.h"
 #include "worker.h"
 
 #include "marshal.h"
@@ -42,8 +43,6 @@
 #include <errno.h>
 #include <fcntl.h>
 
-#include <pthread.h>
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -424,15 +423,13 @@ struct _WorkerSyncObject
   GObject parent_object;
 
   OchushaNetworkBroker *broker;
-  pthread_mutex_t lock;
-  pthread_cond_t cond;
+  Monitor *monitor;
   guint timeout_id;
   guint poll_id;
   volatile guint timeout_count;
   volatile gboolean read_ok;
   volatile gboolean finished;
   volatile gboolean interrupted;
-  volatile gboolean lock_and_cond_initialized;
 };
 
 
@@ -491,18 +488,7 @@ worker_sync_object_class_init(WorkerSyncObjectClass *klass)
 static void
 worker_sync_object_init(WorkerSyncObject *sync_object)
 {
-  if (pthread_mutex_init(&sync_object->lock, NULL) != 0)
-    {
-      fprintf(stderr, "Couldn't init a mutex.\n");
-      abort();
-    }
-
-  if (pthread_cond_init(&sync_object->cond, NULL) != 0)
-    {
-      fprintf(stderr, "Couldn't init a condition.\n");
-      abort();
-    }
-  sync_object->lock_and_cond_initialized = TRUE;
+  sync_object->monitor = ochusha_monitor_new(NULL);
 }
 
 
@@ -515,19 +501,10 @@ worker_sync_object_finalize(GObject *object)
   fprintf(stderr, "worker_sync_object_finalize.\n");
 #endif
 
-  if (sync_object->lock_and_cond_initialized)
+  if (sync_object->monitor != NULL)
     {
-      if (pthread_mutex_destroy(&sync_object->lock) != 0)
-	{
-	  fprintf(stderr, "Couldn't destroy a mutex: errno=%d\n", errno);
-	  abort();
-	}
-      if (pthread_cond_destroy(&sync_object->cond) != 0)
-	{
-	  fprintf(stderr, "Couldn't destroy a condition: errno=%d\n", errno);
-	  abort();
-	}
-      sync_object->lock_and_cond_initialized = FALSE;
+      ochusha_monitor_free(sync_object->monitor);
+      sync_object->monitor = NULL;
     }
 
   if (sync_object_parent_class->finalize)
@@ -548,22 +525,14 @@ worker_sync_object_new(OchushaNetworkBroker *broker)
 #define LOCK_WORKER_SYNC_OBJECT(sync_object)			\
   do								\
     {								\
-      if (pthread_mutex_lock(&(sync_object)->lock) != 0)	\
-	{							\
-	  fprintf(stderr, "Couldn't lock a mutex.\n");		\
-	  abort();						\
-	}							\
+      ochusha_monitor_enter(sync_object->monitor);		\
     }								\
   while (0)
 
 #define UNLOCK_WORKER_SYNC_OBJECT(sync_object)			\
   do								\
     {								\
-      if (pthread_mutex_unlock(&(sync_object)->lock) != 0)	\
-	{							\
-	  fprintf(stderr, "Couldn't unlock a mutex.\n");	\
-	  abort();						\
-	}							\
+      ochusha_monitor_exit(sync_object->monitor);		\
     }								\
   while (0)
 
@@ -580,11 +549,7 @@ timeout_cb(WorkerSyncObject *sync_object)
   LOCK_WORKER_SYNC_OBJECT(sync_object);
   sync_object->timeout_count++;
   finished = sync_object->finished;
-  if (pthread_cond_signal(&sync_object->cond) != 0)
-    {
-      fprintf(stderr, "Couldn't signal a condition.\n");
-      abort();
-    }
+  ochusha_monitor_notify(sync_object->monitor);
   UNLOCK_WORKER_SYNC_OBJECT(sync_object);
 
 #if DEBUG_NETWORK_MOST
@@ -619,11 +584,7 @@ poll_cb(GIOChannel *channel, GIOCondition condition,
   if (condition & (G_IO_IN | G_IO_PRI))
     sync_object->read_ok = TRUE;
 
-  if (pthread_cond_signal(&sync_object->cond) != 0)
-    {
-      fprintf(stderr, "Couldn't signal a condition.\n");
-      abort();
-    }
+  ochusha_monitor_notify(sync_object->monitor);
   sync_object->poll_id = 0;
   UNLOCK_WORKER_SYNC_OBJECT(sync_object);
 
@@ -1008,12 +969,8 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 	    register_polling_function_for_read(sync_object, sock_fd);
 	}
 
-      if (!sync_object->interrupted
-	  && pthread_cond_wait(&sync_object->cond, &sync_object->lock) != 0)
-	{
-	  fprintf(stderr, "Couldn't wait a condition.\n");
-	  abort();
-	}
+      if (!sync_object)
+	ochusha_monitor_wait(sync_object->monitor);
       UNLOCK_WORKER_SYNC_OBJECT(sync_object);
     }
 
@@ -1164,11 +1121,7 @@ wakeup_now_cb(OchushaAsyncBuffer *buffer, WorkerSyncObject *sync_object)
 
   LOCK_WORKER_SYNC_OBJECT(sync_object);
   sync_object->interrupted = TRUE;
-  if (pthread_cond_signal(&sync_object->cond) != 0)
-    {
-      fprintf(stderr, "Couldn't signal a condition.\n");
-      abort();
-    }
+  ochusha_monitor_notify(sync_object->monitor);
   UNLOCK_WORKER_SYNC_OBJECT(sync_object);
 
 #if DEBUG_NETWORK_MOST
@@ -1628,13 +1581,8 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 		register_polling_function_for_read(sync_object, sock_fd);
 	    }
 
-	  if (!sync_object->interrupted
-	      && pthread_cond_wait(&sync_object->cond,
-				   &sync_object->lock) != 0)
-	    {
-	      fprintf(stderr, "Couldn't wait a condition.\n");
-	      abort();
-	    }
+	  if (!sync_object->interrupted)
+	    ochusha_monitor_wait(sync_object->monitor);
 	  UNLOCK_WORKER_SYNC_OBJECT(sync_object);
 	}
 
